/*!
 *   AdminLTE v3.0.0
 *     Only Components
 *   Author: Colorlib
 *	 Website: AdminLTE.io <http://adminlte.io>
 *   License: Open source - MIT <http://opensource.org/licenses/MIT>
 */
.form-group.has-icon {
  position: relative;
}

.form-group.has-icon .form-control {
  padding-right: 35px;
}

.form-group.has-icon .form-icon {
  background-color: transparent;
  border: 0;
  cursor: pointer;
  font-size: 1rem;
  padding: 0.375rem 0.75rem;
  position: absolute;
  right: 3px;
  top: 0;
}

.btn-group-vertical .btn.btn-flat:first-of-type, .btn-group-vertical .btn.btn-flat:last-of-type {
  border-radius: 0;
}

.form-control-feedback.fa, .form-control-feedback.fas, .form-control-feedback.far, .form-control-feedback.fab, .form-control-feedback.glyphicon, .form-control-feedback.ion {
  line-height: calc(2.25rem + 2px);
}

.input-lg + .form-control-feedback.fa, .input-lg + .form-control-feedback.fas, .input-lg + .form-control-feedback.far, .input-lg + .form-control-feedback.fab, .input-lg + .form-control-feedback.glyphicon, .input-lg + .form-control-feedback.ion,
.input-group-lg + .form-control-feedback.fa,
.input-group-lg + .form-control-feedback.fas,
.input-group-lg + .form-control-feedback.far,
.input-group-lg + .form-control-feedback.fab,
.input-group-lg + .form-control-feedback.glyphicon,
.input-group-lg + .form-control-feedback.ion {
  line-height: calc(2.875rem + 2px);
}

.form-group-lg .form-control + .form-control-feedback.fa, .form-group-lg .form-control + .form-control-feedback.fas, .form-group-lg .form-control + .form-control-feedback.far, .form-group-lg .form-control + .form-control-feedback.fab, .form-group-lg .form-control + .form-control-feedback.glyphicon, .form-group-lg .form-control + .form-control-feedback.ion {
  line-height: calc(2.875rem + 2px);
}

.input-sm + .form-control-feedback.fa, .input-sm + .form-control-feedback.fas, .input-sm + .form-control-feedback.far, .input-sm + .form-control-feedback.fab, .input-sm + .form-control-feedback.glyphicon, .input-sm + .form-control-feedback.ion,
.input-group-sm + .form-control-feedback.fa,
.input-group-sm + .form-control-feedback.fas,
.input-group-sm + .form-control-feedback.far,
.input-group-sm + .form-control-feedback.fab,
.input-group-sm + .form-control-feedback.glyphicon,
.input-group-sm + .form-control-feedback.ion {
  line-height: calc(1.8125rem + 2px);
}

.form-group-sm .form-control + .form-control-feedback.fa, .form-group-sm .form-control + .form-control-feedback.fas, .form-group-sm .form-control + .form-control-feedback.far, .form-group-sm .form-control + .form-control-feedback.fab, .form-group-sm .form-control + .form-control-feedback.glyphicon, .form-group-sm .form-control + .form-control-feedback.ion {
  line-height: calc(1.8125rem + 2px);
}

label:not(.form-check-label, .custom-file-label) {
  font-weight: 700;
}

.warning-feedback {
  font-size: 80%;
  color: #ffc107;
  display: none;
  margin-top: 0.25rem;
  width: 100%;
}

.warning-tooltip {
  border-radius: 0.25rem;
  font-size: 0.875rem;
  background-color: rgba(255, 193, 7, 0.9);
  color: #1F2D3D;
  display: none;
  line-height: 1.5;
  margin-top: .1rem;
  max-width: 100%;
  padding: 0.25rem 0.5rem;
  position: absolute;
  top: 100%;
  z-index: 5;
}

.form-control.is-warning {
  border-color: #ffc107;
}

.form-control.is-warning:focus {
  border-color: #ffc107;
  box-shadow: 0 0 0 0 rgba(255, 193, 7, 0.25);
}

.form-control.is-warning ~ .warning-feedback,
.form-control.is-warning ~ .warning-tooltip {
  display: block;
}

textarea.form-control.is-warning {
  padding-right: 2.25rem;
  background-position: top calc(0.375em + 0.1875rem) right calc(0.375em + 0.1875rem);
}

.custom-select.is-warning {
  border-color: #ffc107;
}

.custom-select.is-warning:focus {
  border-color: #ffc107;
  box-shadow: 0 0 0 0 rgba(255, 193, 7, 0.25);
}

.custom-select.is-warning ~ .warning-feedback,
.custom-select.is-warning ~ .warning-tooltip {
  display: block;
}

.form-control-file.is-warning ~ .warning-feedback,
.form-control-file.is-warning ~ .warning-tooltip {
  display: block;
}

.form-check-input.is-warning ~ .form-check-label {
  color: #ffc107;
}

.form-check-input.is-warning ~ .warning-feedback,
.form-check-input.is-warning ~ .warning-tooltip {
  display: block;
}

.custom-control-input.is-warning ~ .custom-control-label {
  color: #ffc107;
}

.custom-control-input.is-warning ~ .custom-control-label::before {
  border-color: #ffc107;
}

.custom-control-input.is-warning ~ .warning-feedback,
.custom-control-input.is-warning ~ .warning-tooltip {
  display: block;
}

.custom-control-input.is-warning:checked ~ .custom-control-label::before {
  background-color: #ffce3a;
  border-color: #ffce3a;
}

.custom-control-input.is-warning:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 0 rgba(255, 193, 7, 0.25);
}

.custom-control-input.is-warning:focus:not(:checked) ~ .custom-control-label::before {
  border-color: #ffc107;
}

.custom-file-input.is-warning ~ .custom-file-label {
  border-color: #ffc107;
}

.custom-file-input.is-warning ~ .warning-feedback,
.custom-file-input.is-warning ~ .warning-tooltip {
  display: block;
}

.custom-file-input.is-warning:focus ~ .custom-file-label {
  border-color: #ffc107;
  box-shadow: 0 0 0 0 rgba(255, 193, 7, 0.25);
}

.custom-switch.custom-switch-off-primary .custom-control-input ~ .custom-control-label::before {
  background: #007bff;
  border-color: #004a99;
}

.custom-switch.custom-switch-off-primary .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-switch.custom-switch-off-primary .custom-control-input ~ .custom-control-label::after {
  background: #003e80;
}

.custom-switch.custom-switch-on-primary .custom-control-input:checked ~ .custom-control-label::before {
  background: #007bff;
  border-color: #004a99;
}

.custom-switch.custom-switch-on-primary .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-switch.custom-switch-on-primary .custom-control-input:checked ~ .custom-control-label::after {
  background: #99caff;
}

.custom-switch.custom-switch-off-secondary .custom-control-input ~ .custom-control-label::before {
  background: #6c757d;
  border-color: #3d4246;
}

.custom-switch.custom-switch-off-secondary .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-switch.custom-switch-off-secondary .custom-control-input ~ .custom-control-label::after {
  background: #313539;
}

.custom-switch.custom-switch-on-secondary .custom-control-input:checked ~ .custom-control-label::before {
  background: #6c757d;
  border-color: #3d4246;
}

.custom-switch.custom-switch-on-secondary .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-switch.custom-switch-on-secondary .custom-control-input:checked ~ .custom-control-label::after {
  background: #bcc1c6;
}

.custom-switch.custom-switch-off-success .custom-control-input ~ .custom-control-label::before {
  background: #28a745;
  border-color: #145523;
}

.custom-switch.custom-switch-off-success .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-switch.custom-switch-off-success .custom-control-input ~ .custom-control-label::after {
  background: #0f401b;
}

.custom-switch.custom-switch-on-success .custom-control-input:checked ~ .custom-control-label::before {
  background: #28a745;
  border-color: #145523;
}

.custom-switch.custom-switch-on-success .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-switch.custom-switch-on-success .custom-control-input:checked ~ .custom-control-label::after {
  background: #86e29b;
}

.custom-switch.custom-switch-off-info .custom-control-input ~ .custom-control-label::before {
  background: #17a2b8;
  border-color: #0c525d;
}

.custom-switch.custom-switch-off-info .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-switch.custom-switch-off-info .custom-control-input ~ .custom-control-label::after {
  background: #093e47;
}

.custom-switch.custom-switch-on-info .custom-control-input:checked ~ .custom-control-label::before {
  background: #17a2b8;
  border-color: #0c525d;
}

.custom-switch.custom-switch-on-info .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-switch.custom-switch-on-info .custom-control-input:checked ~ .custom-control-label::after {
  background: #7adeee;
}

.custom-switch.custom-switch-off-warning .custom-control-input ~ .custom-control-label::before {
  background: #ffc107;
  border-color: #a07800;
}

.custom-switch.custom-switch-off-warning .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-switch.custom-switch-off-warning .custom-control-input ~ .custom-control-label::after {
  background: #876500;
}

.custom-switch.custom-switch-on-warning .custom-control-input:checked ~ .custom-control-label::before {
  background: #ffc107;
  border-color: #a07800;
}

.custom-switch.custom-switch-on-warning .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-switch.custom-switch-on-warning .custom-control-input:checked ~ .custom-control-label::after {
  background: #ffe7a0;
}

.custom-switch.custom-switch-off-danger .custom-control-input ~ .custom-control-label::before {
  background: #dc3545;
  border-color: #921925;
}

.custom-switch.custom-switch-off-danger .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-switch.custom-switch-off-danger .custom-control-input ~ .custom-control-label::after {
  background: #7c151f;
}

.custom-switch.custom-switch-on-danger .custom-control-input:checked ~ .custom-control-label::before {
  background: #dc3545;
  border-color: #921925;
}

.custom-switch.custom-switch-on-danger .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-switch.custom-switch-on-danger .custom-control-input:checked ~ .custom-control-label::after {
  background: #f3b7bd;
}

.custom-switch.custom-switch-off-light .custom-control-input ~ .custom-control-label::before {
  background: #f8f9fa;
  border-color: #bdc6d0;
}

.custom-switch.custom-switch-off-light .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(248, 249, 250, 0.25);
}

.custom-switch.custom-switch-off-light .custom-control-input ~ .custom-control-label::after {
  background: #aeb9c5;
}

.custom-switch.custom-switch-on-light .custom-control-input:checked ~ .custom-control-label::before {
  background: #f8f9fa;
  border-color: #bdc6d0;
}

.custom-switch.custom-switch-on-light .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(248, 249, 250, 0.25);
}

.custom-switch.custom-switch-on-light .custom-control-input:checked ~ .custom-control-label::after {
  background: white;
}

.custom-switch.custom-switch-off-dark .custom-control-input ~ .custom-control-label::before {
  background: #343a40;
  border-color: #060708;
}

.custom-switch.custom-switch-off-dark .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-switch.custom-switch-off-dark .custom-control-input ~ .custom-control-label::after {
  background: black;
}

.custom-switch.custom-switch-on-dark .custom-control-input:checked ~ .custom-control-label::before {
  background: #343a40;
  border-color: #060708;
}

.custom-switch.custom-switch-on-dark .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-switch.custom-switch-on-dark .custom-control-input:checked ~ .custom-control-label::after {
  background: #7a8793;
}

.custom-switch.custom-switch-off-navy .custom-control-input ~ .custom-control-label::before {
  background: #001f3f;
  border-color: black;
}

.custom-switch.custom-switch-off-navy .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 31, 63, 0.25);
}

.custom-switch.custom-switch-off-navy .custom-control-input ~ .custom-control-label::after {
  background: black;
}

.custom-switch.custom-switch-on-navy .custom-control-input:checked ~ .custom-control-label::before {
  background: #001f3f;
  border-color: black;
}

.custom-switch.custom-switch-on-navy .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 31, 63, 0.25);
}

.custom-switch.custom-switch-on-navy .custom-control-input:checked ~ .custom-control-label::after {
  background: #006ad8;
}

.custom-switch.custom-switch-off-olive .custom-control-input ~ .custom-control-label::before {
  background: #3d9970;
  border-color: #20503b;
}

.custom-switch.custom-switch-off-olive .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(61, 153, 112, 0.25);
}

.custom-switch.custom-switch-off-olive .custom-control-input ~ .custom-control-label::after {
  background: #193e2d;
}

.custom-switch.custom-switch-on-olive .custom-control-input:checked ~ .custom-control-label::before {
  background: #3d9970;
  border-color: #20503b;
}

.custom-switch.custom-switch-on-olive .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(61, 153, 112, 0.25);
}

.custom-switch.custom-switch-on-olive .custom-control-input:checked ~ .custom-control-label::after {
  background: #99d6bb;
}

.custom-switch.custom-switch-off-lime .custom-control-input ~ .custom-control-label::before {
  background: #01ff70;
  border-color: #009a43;
}

.custom-switch.custom-switch-off-lime .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(1, 255, 112, 0.25);
}

.custom-switch.custom-switch-off-lime .custom-control-input ~ .custom-control-label::after {
  background: #008138;
}

.custom-switch.custom-switch-on-lime .custom-control-input:checked ~ .custom-control-label::before {
  background: #01ff70;
  border-color: #009a43;
}

.custom-switch.custom-switch-on-lime .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(1, 255, 112, 0.25);
}

.custom-switch.custom-switch-on-lime .custom-control-input:checked ~ .custom-control-label::after {
  background: #9affc6;
}

.custom-switch.custom-switch-off-fuchsia .custom-control-input ~ .custom-control-label::before {
  background: #f012be;
  border-color: #930974;
}

.custom-switch.custom-switch-off-fuchsia .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(240, 18, 190, 0.25);
}

.custom-switch.custom-switch-off-fuchsia .custom-control-input ~ .custom-control-label::after {
  background: #7b0861;
}

.custom-switch.custom-switch-on-fuchsia .custom-control-input:checked ~ .custom-control-label::before {
  background: #f012be;
  border-color: #930974;
}

.custom-switch.custom-switch-on-fuchsia .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(240, 18, 190, 0.25);
}

.custom-switch.custom-switch-on-fuchsia .custom-control-input:checked ~ .custom-control-label::after {
  background: #f9a2e5;
}

.custom-switch.custom-switch-off-maroon .custom-control-input ~ .custom-control-label::before {
  background: #d81b60;
  border-color: #7d1038;
}

.custom-switch.custom-switch-off-maroon .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(216, 27, 96, 0.25);
}

.custom-switch.custom-switch-off-maroon .custom-control-input ~ .custom-control-label::after {
  background: #670d2e;
}

.custom-switch.custom-switch-on-maroon .custom-control-input:checked ~ .custom-control-label::before {
  background: #d81b60;
  border-color: #7d1038;
}

.custom-switch.custom-switch-on-maroon .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(216, 27, 96, 0.25);
}

.custom-switch.custom-switch-on-maroon .custom-control-input:checked ~ .custom-control-label::after {
  background: #f29aba;
}

.custom-switch.custom-switch-off-blue .custom-control-input ~ .custom-control-label::before {
  background: #007bff;
  border-color: #004a99;
}

.custom-switch.custom-switch-off-blue .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-switch.custom-switch-off-blue .custom-control-input ~ .custom-control-label::after {
  background: #003e80;
}

.custom-switch.custom-switch-on-blue .custom-control-input:checked ~ .custom-control-label::before {
  background: #007bff;
  border-color: #004a99;
}

.custom-switch.custom-switch-on-blue .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-switch.custom-switch-on-blue .custom-control-input:checked ~ .custom-control-label::after {
  background: #99caff;
}

.custom-switch.custom-switch-off-indigo .custom-control-input ~ .custom-control-label::before {
  background: #6610f2;
  border-color: #3d0894;
}

.custom-switch.custom-switch-off-indigo .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(102, 16, 242, 0.25);
}

.custom-switch.custom-switch-off-indigo .custom-control-input ~ .custom-control-label::after {
  background: #33077c;
}

.custom-switch.custom-switch-on-indigo .custom-control-input:checked ~ .custom-control-label::before {
  background: #6610f2;
  border-color: #3d0894;
}

.custom-switch.custom-switch-on-indigo .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(102, 16, 242, 0.25);
}

.custom-switch.custom-switch-on-indigo .custom-control-input:checked ~ .custom-control-label::after {
  background: #c3a1fa;
}

.custom-switch.custom-switch-off-purple .custom-control-input ~ .custom-control-label::before {
  background: #6f42c1;
  border-color: #432776;
}

.custom-switch.custom-switch-off-purple .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(111, 66, 193, 0.25);
}

.custom-switch.custom-switch-off-purple .custom-control-input ~ .custom-control-label::after {
  background: #382063;
}

.custom-switch.custom-switch-on-purple .custom-control-input:checked ~ .custom-control-label::before {
  background: #6f42c1;
  border-color: #432776;
}

.custom-switch.custom-switch-on-purple .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(111, 66, 193, 0.25);
}

.custom-switch.custom-switch-on-purple .custom-control-input:checked ~ .custom-control-label::after {
  background: #c7b5e7;
}

.custom-switch.custom-switch-off-pink .custom-control-input ~ .custom-control-label::before {
  background: #e83e8c;
  border-color: #ac145a;
}

.custom-switch.custom-switch-off-pink .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(232, 62, 140, 0.25);
}

.custom-switch.custom-switch-off-pink .custom-control-input ~ .custom-control-label::after {
  background: #95124e;
}

.custom-switch.custom-switch-on-pink .custom-control-input:checked ~ .custom-control-label::before {
  background: #e83e8c;
  border-color: #ac145a;
}

.custom-switch.custom-switch-on-pink .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(232, 62, 140, 0.25);
}

.custom-switch.custom-switch-on-pink .custom-control-input:checked ~ .custom-control-label::after {
  background: #f8c7dd;
}

.custom-switch.custom-switch-off-red .custom-control-input ~ .custom-control-label::before {
  background: #dc3545;
  border-color: #921925;
}

.custom-switch.custom-switch-off-red .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-switch.custom-switch-off-red .custom-control-input ~ .custom-control-label::after {
  background: #7c151f;
}

.custom-switch.custom-switch-on-red .custom-control-input:checked ~ .custom-control-label::before {
  background: #dc3545;
  border-color: #921925;
}

.custom-switch.custom-switch-on-red .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-switch.custom-switch-on-red .custom-control-input:checked ~ .custom-control-label::after {
  background: #f3b7bd;
}

.custom-switch.custom-switch-off-orange .custom-control-input ~ .custom-control-label::before {
  background: #fd7e14;
  border-color: #aa4e01;
}

.custom-switch.custom-switch-off-orange .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(253, 126, 20, 0.25);
}

.custom-switch.custom-switch-off-orange .custom-control-input ~ .custom-control-label::after {
  background: #904201;
}

.custom-switch.custom-switch-on-orange .custom-control-input:checked ~ .custom-control-label::before {
  background: #fd7e14;
  border-color: #aa4e01;
}

.custom-switch.custom-switch-on-orange .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(253, 126, 20, 0.25);
}

.custom-switch.custom-switch-on-orange .custom-control-input:checked ~ .custom-control-label::after {
  background: #fed1ac;
}

.custom-switch.custom-switch-off-yellow .custom-control-input ~ .custom-control-label::before {
  background: #ffc107;
  border-color: #a07800;
}

.custom-switch.custom-switch-off-yellow .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-switch.custom-switch-off-yellow .custom-control-input ~ .custom-control-label::after {
  background: #876500;
}

.custom-switch.custom-switch-on-yellow .custom-control-input:checked ~ .custom-control-label::before {
  background: #ffc107;
  border-color: #a07800;
}

.custom-switch.custom-switch-on-yellow .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-switch.custom-switch-on-yellow .custom-control-input:checked ~ .custom-control-label::after {
  background: #ffe7a0;
}

.custom-switch.custom-switch-off-green .custom-control-input ~ .custom-control-label::before {
  background: #28a745;
  border-color: #145523;
}

.custom-switch.custom-switch-off-green .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-switch.custom-switch-off-green .custom-control-input ~ .custom-control-label::after {
  background: #0f401b;
}

.custom-switch.custom-switch-on-green .custom-control-input:checked ~ .custom-control-label::before {
  background: #28a745;
  border-color: #145523;
}

.custom-switch.custom-switch-on-green .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-switch.custom-switch-on-green .custom-control-input:checked ~ .custom-control-label::after {
  background: #86e29b;
}

.custom-switch.custom-switch-off-teal .custom-control-input ~ .custom-control-label::before {
  background: #20c997;
  border-color: #127155;
}

.custom-switch.custom-switch-off-teal .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(32, 201, 151, 0.25);
}

.custom-switch.custom-switch-off-teal .custom-control-input ~ .custom-control-label::after {
  background: #0e5b44;
}

.custom-switch.custom-switch-on-teal .custom-control-input:checked ~ .custom-control-label::before {
  background: #20c997;
  border-color: #127155;
}

.custom-switch.custom-switch-on-teal .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(32, 201, 151, 0.25);
}

.custom-switch.custom-switch-on-teal .custom-control-input:checked ~ .custom-control-label::after {
  background: #94eed3;
}

.custom-switch.custom-switch-off-cyan .custom-control-input ~ .custom-control-label::before {
  background: #17a2b8;
  border-color: #0c525d;
}

.custom-switch.custom-switch-off-cyan .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-switch.custom-switch-off-cyan .custom-control-input ~ .custom-control-label::after {
  background: #093e47;
}

.custom-switch.custom-switch-on-cyan .custom-control-input:checked ~ .custom-control-label::before {
  background: #17a2b8;
  border-color: #0c525d;
}

.custom-switch.custom-switch-on-cyan .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-switch.custom-switch-on-cyan .custom-control-input:checked ~ .custom-control-label::after {
  background: #7adeee;
}

.custom-switch.custom-switch-off-white .custom-control-input ~ .custom-control-label::before {
  background: #ffffff;
  border-color: #cccccc;
}

.custom-switch.custom-switch-off-white .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 255, 255, 0.25);
}

.custom-switch.custom-switch-off-white .custom-control-input ~ .custom-control-label::after {
  background: #bfbfbf;
}

.custom-switch.custom-switch-on-white .custom-control-input:checked ~ .custom-control-label::before {
  background: #ffffff;
  border-color: #cccccc;
}

.custom-switch.custom-switch-on-white .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 255, 255, 0.25);
}

.custom-switch.custom-switch-on-white .custom-control-input:checked ~ .custom-control-label::after {
  background: white;
}

.custom-switch.custom-switch-off-gray .custom-control-input ~ .custom-control-label::before {
  background: #6c757d;
  border-color: #3d4246;
}

.custom-switch.custom-switch-off-gray .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-switch.custom-switch-off-gray .custom-control-input ~ .custom-control-label::after {
  background: #313539;
}

.custom-switch.custom-switch-on-gray .custom-control-input:checked ~ .custom-control-label::before {
  background: #6c757d;
  border-color: #3d4246;
}

.custom-switch.custom-switch-on-gray .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-switch.custom-switch-on-gray .custom-control-input:checked ~ .custom-control-label::after {
  background: #bcc1c6;
}

.custom-switch.custom-switch-off-gray-dark .custom-control-input ~ .custom-control-label::before {
  background: #343a40;
  border-color: #060708;
}

.custom-switch.custom-switch-off-gray-dark .custom-control-input:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-switch.custom-switch-off-gray-dark .custom-control-input ~ .custom-control-label::after {
  background: black;
}

.custom-switch.custom-switch-on-gray-dark .custom-control-input:checked ~ .custom-control-label::before {
  background: #343a40;
  border-color: #060708;
}

.custom-switch.custom-switch-on-gray-dark .custom-control-input:checked:focus ~ .custom-control-label::before {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-switch.custom-switch-on-gray-dark .custom-control-input:checked ~ .custom-control-label::after {
  background: #7a8793;
}

.custom-range.custom-range-primary:focus {
  outline: none;
}

.custom-range.custom-range-primary:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-range.custom-range-primary:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-range.custom-range-primary:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-range.custom-range-primary::-webkit-slider-thumb {
  background-color: #007bff;
}

.custom-range.custom-range-primary::-webkit-slider-thumb:active {
  background-color: #b3d7ff;
}

.custom-range.custom-range-primary::-moz-range-thumb {
  background-color: #007bff;
}

.custom-range.custom-range-primary::-moz-range-thumb:active {
  background-color: #b3d7ff;
}

.custom-range.custom-range-primary::-ms-thumb {
  background-color: #007bff;
}

.custom-range.custom-range-primary::-ms-thumb:active {
  background-color: #b3d7ff;
}

.custom-range.custom-range-secondary:focus {
  outline: none;
}

.custom-range.custom-range-secondary:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-range.custom-range-secondary:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-range.custom-range-secondary:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-range.custom-range-secondary::-webkit-slider-thumb {
  background-color: #6c757d;
}

.custom-range.custom-range-secondary::-webkit-slider-thumb:active {
  background-color: #caced1;
}

.custom-range.custom-range-secondary::-moz-range-thumb {
  background-color: #6c757d;
}

.custom-range.custom-range-secondary::-moz-range-thumb:active {
  background-color: #caced1;
}

.custom-range.custom-range-secondary::-ms-thumb {
  background-color: #6c757d;
}

.custom-range.custom-range-secondary::-ms-thumb:active {
  background-color: #caced1;
}

.custom-range.custom-range-success:focus {
  outline: none;
}

.custom-range.custom-range-success:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-range.custom-range-success:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-range.custom-range-success:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-range.custom-range-success::-webkit-slider-thumb {
  background-color: #28a745;
}

.custom-range.custom-range-success::-webkit-slider-thumb:active {
  background-color: #9be7ac;
}

.custom-range.custom-range-success::-moz-range-thumb {
  background-color: #28a745;
}

.custom-range.custom-range-success::-moz-range-thumb:active {
  background-color: #9be7ac;
}

.custom-range.custom-range-success::-ms-thumb {
  background-color: #28a745;
}

.custom-range.custom-range-success::-ms-thumb:active {
  background-color: #9be7ac;
}

.custom-range.custom-range-info:focus {
  outline: none;
}

.custom-range.custom-range-info:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-range.custom-range-info:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-range.custom-range-info:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-range.custom-range-info::-webkit-slider-thumb {
  background-color: #17a2b8;
}

.custom-range.custom-range-info::-webkit-slider-thumb:active {
  background-color: #90e4f1;
}

.custom-range.custom-range-info::-moz-range-thumb {
  background-color: #17a2b8;
}

.custom-range.custom-range-info::-moz-range-thumb:active {
  background-color: #90e4f1;
}

.custom-range.custom-range-info::-ms-thumb {
  background-color: #17a2b8;
}

.custom-range.custom-range-info::-ms-thumb:active {
  background-color: #90e4f1;
}

.custom-range.custom-range-warning:focus {
  outline: none;
}

.custom-range.custom-range-warning:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-range.custom-range-warning:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-range.custom-range-warning:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-range.custom-range-warning::-webkit-slider-thumb {
  background-color: #ffc107;
}

.custom-range.custom-range-warning::-webkit-slider-thumb:active {
  background-color: #ffeeba;
}

.custom-range.custom-range-warning::-moz-range-thumb {
  background-color: #ffc107;
}

.custom-range.custom-range-warning::-moz-range-thumb:active {
  background-color: #ffeeba;
}

.custom-range.custom-range-warning::-ms-thumb {
  background-color: #ffc107;
}

.custom-range.custom-range-warning::-ms-thumb:active {
  background-color: #ffeeba;
}

.custom-range.custom-range-danger:focus {
  outline: none;
}

.custom-range.custom-range-danger:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-range.custom-range-danger:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-range.custom-range-danger:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-range.custom-range-danger::-webkit-slider-thumb {
  background-color: #dc3545;
}

.custom-range.custom-range-danger::-webkit-slider-thumb:active {
  background-color: #f6cdd1;
}

.custom-range.custom-range-danger::-moz-range-thumb {
  background-color: #dc3545;
}

.custom-range.custom-range-danger::-moz-range-thumb:active {
  background-color: #f6cdd1;
}

.custom-range.custom-range-danger::-ms-thumb {
  background-color: #dc3545;
}

.custom-range.custom-range-danger::-ms-thumb:active {
  background-color: #f6cdd1;
}

.custom-range.custom-range-light:focus {
  outline: none;
}

.custom-range.custom-range-light:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(248, 249, 250, 0.25);
}

.custom-range.custom-range-light:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(248, 249, 250, 0.25);
}

.custom-range.custom-range-light:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(248, 249, 250, 0.25);
}

.custom-range.custom-range-light::-webkit-slider-thumb {
  background-color: #f8f9fa;
}

.custom-range.custom-range-light::-webkit-slider-thumb:active {
  background-color: white;
}

.custom-range.custom-range-light::-moz-range-thumb {
  background-color: #f8f9fa;
}

.custom-range.custom-range-light::-moz-range-thumb:active {
  background-color: white;
}

.custom-range.custom-range-light::-ms-thumb {
  background-color: #f8f9fa;
}

.custom-range.custom-range-light::-ms-thumb:active {
  background-color: white;
}

.custom-range.custom-range-dark:focus {
  outline: none;
}

.custom-range.custom-range-dark:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-range.custom-range-dark:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-range.custom-range-dark:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-range.custom-range-dark::-webkit-slider-thumb {
  background-color: #343a40;
}

.custom-range.custom-range-dark::-webkit-slider-thumb:active {
  background-color: #88939e;
}

.custom-range.custom-range-dark::-moz-range-thumb {
  background-color: #343a40;
}

.custom-range.custom-range-dark::-moz-range-thumb:active {
  background-color: #88939e;
}

.custom-range.custom-range-dark::-ms-thumb {
  background-color: #343a40;
}

.custom-range.custom-range-dark::-ms-thumb:active {
  background-color: #88939e;
}

.custom-range.custom-range-navy:focus {
  outline: none;
}

.custom-range.custom-range-navy:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 31, 63, 0.25);
}

.custom-range.custom-range-navy:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 31, 63, 0.25);
}

.custom-range.custom-range-navy:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 31, 63, 0.25);
}

.custom-range.custom-range-navy::-webkit-slider-thumb {
  background-color: #001f3f;
}

.custom-range.custom-range-navy::-webkit-slider-thumb:active {
  background-color: #0077f2;
}

.custom-range.custom-range-navy::-moz-range-thumb {
  background-color: #001f3f;
}

.custom-range.custom-range-navy::-moz-range-thumb:active {
  background-color: #0077f2;
}

.custom-range.custom-range-navy::-ms-thumb {
  background-color: #001f3f;
}

.custom-range.custom-range-navy::-ms-thumb:active {
  background-color: #0077f2;
}

.custom-range.custom-range-olive:focus {
  outline: none;
}

.custom-range.custom-range-olive:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(61, 153, 112, 0.25);
}

.custom-range.custom-range-olive:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(61, 153, 112, 0.25);
}

.custom-range.custom-range-olive:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(61, 153, 112, 0.25);
}

.custom-range.custom-range-olive::-webkit-slider-thumb {
  background-color: #3d9970;
}

.custom-range.custom-range-olive::-webkit-slider-thumb:active {
  background-color: #abdec7;
}

.custom-range.custom-range-olive::-moz-range-thumb {
  background-color: #3d9970;
}

.custom-range.custom-range-olive::-moz-range-thumb:active {
  background-color: #abdec7;
}

.custom-range.custom-range-olive::-ms-thumb {
  background-color: #3d9970;
}

.custom-range.custom-range-olive::-ms-thumb:active {
  background-color: #abdec7;
}

.custom-range.custom-range-lime:focus {
  outline: none;
}

.custom-range.custom-range-lime:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(1, 255, 112, 0.25);
}

.custom-range.custom-range-lime:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(1, 255, 112, 0.25);
}

.custom-range.custom-range-lime:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(1, 255, 112, 0.25);
}

.custom-range.custom-range-lime::-webkit-slider-thumb {
  background-color: #01ff70;
}

.custom-range.custom-range-lime::-webkit-slider-thumb:active {
  background-color: #b4ffd4;
}

.custom-range.custom-range-lime::-moz-range-thumb {
  background-color: #01ff70;
}

.custom-range.custom-range-lime::-moz-range-thumb:active {
  background-color: #b4ffd4;
}

.custom-range.custom-range-lime::-ms-thumb {
  background-color: #01ff70;
}

.custom-range.custom-range-lime::-ms-thumb:active {
  background-color: #b4ffd4;
}

.custom-range.custom-range-fuchsia:focus {
  outline: none;
}

.custom-range.custom-range-fuchsia:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(240, 18, 190, 0.25);
}

.custom-range.custom-range-fuchsia:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(240, 18, 190, 0.25);
}

.custom-range.custom-range-fuchsia:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(240, 18, 190, 0.25);
}

.custom-range.custom-range-fuchsia::-webkit-slider-thumb {
  background-color: #f012be;
}

.custom-range.custom-range-fuchsia::-webkit-slider-thumb:active {
  background-color: #fbbaec;
}

.custom-range.custom-range-fuchsia::-moz-range-thumb {
  background-color: #f012be;
}

.custom-range.custom-range-fuchsia::-moz-range-thumb:active {
  background-color: #fbbaec;
}

.custom-range.custom-range-fuchsia::-ms-thumb {
  background-color: #f012be;
}

.custom-range.custom-range-fuchsia::-ms-thumb:active {
  background-color: #fbbaec;
}

.custom-range.custom-range-maroon:focus {
  outline: none;
}

.custom-range.custom-range-maroon:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(216, 27, 96, 0.25);
}

.custom-range.custom-range-maroon:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(216, 27, 96, 0.25);
}

.custom-range.custom-range-maroon:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(216, 27, 96, 0.25);
}

.custom-range.custom-range-maroon::-webkit-slider-thumb {
  background-color: #d81b60;
}

.custom-range.custom-range-maroon::-webkit-slider-thumb:active {
  background-color: #f5b0c9;
}

.custom-range.custom-range-maroon::-moz-range-thumb {
  background-color: #d81b60;
}

.custom-range.custom-range-maroon::-moz-range-thumb:active {
  background-color: #f5b0c9;
}

.custom-range.custom-range-maroon::-ms-thumb {
  background-color: #d81b60;
}

.custom-range.custom-range-maroon::-ms-thumb:active {
  background-color: #f5b0c9;
}

.custom-range.custom-range-blue:focus {
  outline: none;
}

.custom-range.custom-range-blue:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-range.custom-range-blue:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-range.custom-range-blue:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(0, 123, 255, 0.25);
}

.custom-range.custom-range-blue::-webkit-slider-thumb {
  background-color: #007bff;
}

.custom-range.custom-range-blue::-webkit-slider-thumb:active {
  background-color: #b3d7ff;
}

.custom-range.custom-range-blue::-moz-range-thumb {
  background-color: #007bff;
}

.custom-range.custom-range-blue::-moz-range-thumb:active {
  background-color: #b3d7ff;
}

.custom-range.custom-range-blue::-ms-thumb {
  background-color: #007bff;
}

.custom-range.custom-range-blue::-ms-thumb:active {
  background-color: #b3d7ff;
}

.custom-range.custom-range-indigo:focus {
  outline: none;
}

.custom-range.custom-range-indigo:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(102, 16, 242, 0.25);
}

.custom-range.custom-range-indigo:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(102, 16, 242, 0.25);
}

.custom-range.custom-range-indigo:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(102, 16, 242, 0.25);
}

.custom-range.custom-range-indigo::-webkit-slider-thumb {
  background-color: #6610f2;
}

.custom-range.custom-range-indigo::-webkit-slider-thumb:active {
  background-color: #d2b9fb;
}

.custom-range.custom-range-indigo::-moz-range-thumb {
  background-color: #6610f2;
}

.custom-range.custom-range-indigo::-moz-range-thumb:active {
  background-color: #d2b9fb;
}

.custom-range.custom-range-indigo::-ms-thumb {
  background-color: #6610f2;
}

.custom-range.custom-range-indigo::-ms-thumb:active {
  background-color: #d2b9fb;
}

.custom-range.custom-range-purple:focus {
  outline: none;
}

.custom-range.custom-range-purple:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(111, 66, 193, 0.25);
}

.custom-range.custom-range-purple:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(111, 66, 193, 0.25);
}

.custom-range.custom-range-purple:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(111, 66, 193, 0.25);
}

.custom-range.custom-range-purple::-webkit-slider-thumb {
  background-color: #6f42c1;
}

.custom-range.custom-range-purple::-webkit-slider-thumb:active {
  background-color: #d5c8ed;
}

.custom-range.custom-range-purple::-moz-range-thumb {
  background-color: #6f42c1;
}

.custom-range.custom-range-purple::-moz-range-thumb:active {
  background-color: #d5c8ed;
}

.custom-range.custom-range-purple::-ms-thumb {
  background-color: #6f42c1;
}

.custom-range.custom-range-purple::-ms-thumb:active {
  background-color: #d5c8ed;
}

.custom-range.custom-range-pink:focus {
  outline: none;
}

.custom-range.custom-range-pink:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(232, 62, 140, 0.25);
}

.custom-range.custom-range-pink:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(232, 62, 140, 0.25);
}

.custom-range.custom-range-pink:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(232, 62, 140, 0.25);
}

.custom-range.custom-range-pink::-webkit-slider-thumb {
  background-color: #e83e8c;
}

.custom-range.custom-range-pink::-webkit-slider-thumb:active {
  background-color: #fbddeb;
}

.custom-range.custom-range-pink::-moz-range-thumb {
  background-color: #e83e8c;
}

.custom-range.custom-range-pink::-moz-range-thumb:active {
  background-color: #fbddeb;
}

.custom-range.custom-range-pink::-ms-thumb {
  background-color: #e83e8c;
}

.custom-range.custom-range-pink::-ms-thumb:active {
  background-color: #fbddeb;
}

.custom-range.custom-range-red:focus {
  outline: none;
}

.custom-range.custom-range-red:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-range.custom-range-red:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-range.custom-range-red:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(220, 53, 69, 0.25);
}

.custom-range.custom-range-red::-webkit-slider-thumb {
  background-color: #dc3545;
}

.custom-range.custom-range-red::-webkit-slider-thumb:active {
  background-color: #f6cdd1;
}

.custom-range.custom-range-red::-moz-range-thumb {
  background-color: #dc3545;
}

.custom-range.custom-range-red::-moz-range-thumb:active {
  background-color: #f6cdd1;
}

.custom-range.custom-range-red::-ms-thumb {
  background-color: #dc3545;
}

.custom-range.custom-range-red::-ms-thumb:active {
  background-color: #f6cdd1;
}

.custom-range.custom-range-orange:focus {
  outline: none;
}

.custom-range.custom-range-orange:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(253, 126, 20, 0.25);
}

.custom-range.custom-range-orange:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(253, 126, 20, 0.25);
}

.custom-range.custom-range-orange:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(253, 126, 20, 0.25);
}

.custom-range.custom-range-orange::-webkit-slider-thumb {
  background-color: #fd7e14;
}

.custom-range.custom-range-orange::-webkit-slider-thumb:active {
  background-color: #ffdfc5;
}

.custom-range.custom-range-orange::-moz-range-thumb {
  background-color: #fd7e14;
}

.custom-range.custom-range-orange::-moz-range-thumb:active {
  background-color: #ffdfc5;
}

.custom-range.custom-range-orange::-ms-thumb {
  background-color: #fd7e14;
}

.custom-range.custom-range-orange::-ms-thumb:active {
  background-color: #ffdfc5;
}

.custom-range.custom-range-yellow:focus {
  outline: none;
}

.custom-range.custom-range-yellow:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-range.custom-range-yellow:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-range.custom-range-yellow:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 193, 7, 0.25);
}

.custom-range.custom-range-yellow::-webkit-slider-thumb {
  background-color: #ffc107;
}

.custom-range.custom-range-yellow::-webkit-slider-thumb:active {
  background-color: #ffeeba;
}

.custom-range.custom-range-yellow::-moz-range-thumb {
  background-color: #ffc107;
}

.custom-range.custom-range-yellow::-moz-range-thumb:active {
  background-color: #ffeeba;
}

.custom-range.custom-range-yellow::-ms-thumb {
  background-color: #ffc107;
}

.custom-range.custom-range-yellow::-ms-thumb:active {
  background-color: #ffeeba;
}

.custom-range.custom-range-green:focus {
  outline: none;
}

.custom-range.custom-range-green:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-range.custom-range-green:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-range.custom-range-green:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(40, 167, 69, 0.25);
}

.custom-range.custom-range-green::-webkit-slider-thumb {
  background-color: #28a745;
}

.custom-range.custom-range-green::-webkit-slider-thumb:active {
  background-color: #9be7ac;
}

.custom-range.custom-range-green::-moz-range-thumb {
  background-color: #28a745;
}

.custom-range.custom-range-green::-moz-range-thumb:active {
  background-color: #9be7ac;
}

.custom-range.custom-range-green::-ms-thumb {
  background-color: #28a745;
}

.custom-range.custom-range-green::-ms-thumb:active {
  background-color: #9be7ac;
}

.custom-range.custom-range-teal:focus {
  outline: none;
}

.custom-range.custom-range-teal:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(32, 201, 151, 0.25);
}

.custom-range.custom-range-teal:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(32, 201, 151, 0.25);
}

.custom-range.custom-range-teal:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(32, 201, 151, 0.25);
}

.custom-range.custom-range-teal::-webkit-slider-thumb {
  background-color: #20c997;
}

.custom-range.custom-range-teal::-webkit-slider-thumb:active {
  background-color: #aaf1dc;
}

.custom-range.custom-range-teal::-moz-range-thumb {
  background-color: #20c997;
}

.custom-range.custom-range-teal::-moz-range-thumb:active {
  background-color: #aaf1dc;
}

.custom-range.custom-range-teal::-ms-thumb {
  background-color: #20c997;
}

.custom-range.custom-range-teal::-ms-thumb:active {
  background-color: #aaf1dc;
}

.custom-range.custom-range-cyan:focus {
  outline: none;
}

.custom-range.custom-range-cyan:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-range.custom-range-cyan:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-range.custom-range-cyan:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(23, 162, 184, 0.25);
}

.custom-range.custom-range-cyan::-webkit-slider-thumb {
  background-color: #17a2b8;
}

.custom-range.custom-range-cyan::-webkit-slider-thumb:active {
  background-color: #90e4f1;
}

.custom-range.custom-range-cyan::-moz-range-thumb {
  background-color: #17a2b8;
}

.custom-range.custom-range-cyan::-moz-range-thumb:active {
  background-color: #90e4f1;
}

.custom-range.custom-range-cyan::-ms-thumb {
  background-color: #17a2b8;
}

.custom-range.custom-range-cyan::-ms-thumb:active {
  background-color: #90e4f1;
}

.custom-range.custom-range-white:focus {
  outline: none;
}

.custom-range.custom-range-white:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 255, 255, 0.25);
}

.custom-range.custom-range-white:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 255, 255, 0.25);
}

.custom-range.custom-range-white:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(255, 255, 255, 0.25);
}

.custom-range.custom-range-white::-webkit-slider-thumb {
  background-color: #ffffff;
}

.custom-range.custom-range-white::-webkit-slider-thumb:active {
  background-color: white;
}

.custom-range.custom-range-white::-moz-range-thumb {
  background-color: #ffffff;
}

.custom-range.custom-range-white::-moz-range-thumb:active {
  background-color: white;
}

.custom-range.custom-range-white::-ms-thumb {
  background-color: #ffffff;
}

.custom-range.custom-range-white::-ms-thumb:active {
  background-color: white;
}

.custom-range.custom-range-gray:focus {
  outline: none;
}

.custom-range.custom-range-gray:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-range.custom-range-gray:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-range.custom-range-gray:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(108, 117, 125, 0.25);
}

.custom-range.custom-range-gray::-webkit-slider-thumb {
  background-color: #6c757d;
}

.custom-range.custom-range-gray::-webkit-slider-thumb:active {
  background-color: #caced1;
}

.custom-range.custom-range-gray::-moz-range-thumb {
  background-color: #6c757d;
}

.custom-range.custom-range-gray::-moz-range-thumb:active {
  background-color: #caced1;
}

.custom-range.custom-range-gray::-ms-thumb {
  background-color: #6c757d;
}

.custom-range.custom-range-gray::-ms-thumb:active {
  background-color: #caced1;
}

.custom-range.custom-range-gray-dark:focus {
  outline: none;
}

.custom-range.custom-range-gray-dark:focus::-webkit-slider-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-range.custom-range-gray-dark:focus::-moz-range-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-range.custom-range-gray-dark:focus::-ms-thumb {
  box-shadow: 0 0 0 1px #ffffff, 0 0 0 2px rgba(52, 58, 64, 0.25);
}

.custom-range.custom-range-gray-dark::-webkit-slider-thumb {
  background-color: #343a40;
}

.custom-range.custom-range-gray-dark::-webkit-slider-thumb:active {
  background-color: #88939e;
}

.custom-range.custom-range-gray-dark::-moz-range-thumb {
  background-color: #343a40;
}

.custom-range.custom-range-gray-dark::-moz-range-thumb:active {
  background-color: #88939e;
}

.custom-range.custom-range-gray-dark::-ms-thumb {
  background-color: #343a40;
}

.custom-range.custom-range-gray-dark::-ms-thumb:active {
  background-color: #88939e;
}

.progress {
  box-shadow: none;
  border-radius: 1px;
}

.progress.vertical {
  display: inline-block;
  height: 200px;
  margin-right: 10px;
  position: relative;
  width: 30px;
}

.progress.vertical > .progress-bar {
  bottom: 0;
  position: absolute;
  width: 100%;
}

.progress.vertical.sm, .progress.vertical.progress-sm {
  width: 20px;
}

.progress.vertical.xs, .progress.vertical.progress-xs {
  width: 10px;
}

.progress.vertical.xxs, .progress.vertical.progress-xxs {
  width: 3px;
}

.progress-group {
  margin-bottom: 0.5rem;
}

.progress-sm {
  height: 10px;
}

.progress-xs {
  height: 7px;
}

.progress-xxs {
  height: 3px;
}

.table tr > td .progress {
  margin: 0;
}

.card {
  box-shadow: 0 0 1px rgba(0, 0, 0, 0.125), 0 1px 3px rgba(0, 0, 0, 0.2);
  margin-bottom: 1rem;
}

.card.bg-dark .card-header {
  border-color: #383f45;
}

.card.bg-dark,
.card.bg-dark .card-body {
  color: #ffffff;
}

.card.maximized-card {
  height: 100% !important;
  left: 0;
  max-height: 100% !important;
  max-width: 100% !important;
  position: fixed;
  top: 0;
  width: 100% !important;
  z-index: 9999;
}

.card.maximized-card.was-collapsed .card-body {
  display: block !important;
}

.card.maximized-card [data-widget='collapse'] {
  display: none;
}

.card.maximized-card .card-header,
.card.maximized-card .card-footer {
  border-radius: 0 !important;
}

.card.collapsed-card .card-body,
.card.collapsed-card .card-footer {
  display: none;
}

.card .nav.flex-column > li {
  border-bottom: 1px solid rgba(0, 0, 0, 0.125);
  margin: 0;
}

.card .nav.flex-column > li:last-of-type {
  border-bottom: 0;
}

.card.height-control .card-body {
  max-height: 300px;
  overflow: auto;
}

.card .border-right {
  border-right: 1px solid rgba(0, 0, 0, 0.125);
}

.card .border-left {
  border-left: 1px solid rgba(0, 0, 0, 0.125);
}

.card.card-tabs:not(.card-outline) .card-header {
  border-bottom: 0;
}

.card.card-tabs:not(.card-outline) .card-header .nav-item:first-child .nav-link {
  margin-left: -1px;
}

.card.card-tabs.card-outline .nav-item {
  border-bottom: 0;
}

.card.card-tabs.card-outline .nav-item:first-child .nav-link {
  border-left: 0;
  margin-left: 0;
}

.card.card-outline-tabs {
  border-top: 0;
}

.card.card-outline-tabs .card-header .nav-item:first-child .nav-link {
  border-left: 0;
  margin-left: 0;
}

.card.card-outline-tabs .card-header a {
  border-top: 3px solid transparent;
}

.card.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card.card-outline-tabs .card-header a.active:hover {
  margin-top: 0;
}

html.maximized-card {
  overflow: hidden;
}

.card-header::after,
.card-body::after,
.card-footer::after {
  display: block;
  clear: both;
  content: "";
}

.card-header {
  background-color: transparent;
  border-bottom: 1px solid rgba(0, 0, 0, 0.125);
  padding: 0.75rem 1.25rem;
  position: relative;
  border-top-left-radius: 0.25rem;
  border-top-right-radius: 0.25rem;
}

.collapsed-card .card-header {
  border-bottom: 0;
}

.card-header > .card-tools {
  float: right;
  margin-right: -0.625rem;
}

.card-header > .card-tools .input-group,
.card-header > .card-tools .nav,
.card-header > .card-tools .pagination {
  margin-bottom: -0.3rem;
  margin-top: -0.3rem;
}

.card-header > .card-tools [data-toggle='tooltip'] {
  position: relative;
}

.card-title {
  float: left;
  font-size: 1.1rem;
  font-weight: 400;
  margin: 0;
}

.card-text {
  clear: both;
}

.btn-tool {
  background: transparent;
  color: #adb5bd;
  font-size: 0.875rem;
  margin: -0.75rem 0;
  padding: .25rem .5rem;
}

.btn-group.show .btn-tool, .btn-tool:hover {
  color: #495057;
}

.show .btn-tool, .btn-tool:focus {
  box-shadow: none !important;
}

.text-sm .card-title {
  font-size: 1rem;
}

.text-sm .nav-link {
  padding: 0.4rem 0.8rem;
}

.card-body > .table {
  margin-bottom: 0;
}

.card-body > .table > thead > tr > th,
.card-body > .table > thead > tr > td {
  border-top-width: 0;
}

.card-body .fc {
  margin-top: 5px;
}

.card-body .full-width-chart {
  margin: -19px;
}

.card-body.p-0 .full-width-chart {
  margin: -9px;
}

.chart-legend {
  padding-left: 0;
  list-style: none;
  margin: 10px 0;
}

@media (max-width: 576px) {
  .chart-legend > li {
    float: left;
    margin-right: 10px;
  }
}

.card-comments {
  background: #f8f9fa;
}

.card-comments .card-comment {
  border-bottom: 1px solid #e9ecef;
  padding: 8px 0;
}

.card-comments .card-comment::after {
  display: block;
  clear: both;
  content: "";
}

.card-comments .card-comment:last-of-type {
  border-bottom: 0;
}

.card-comments .card-comment:first-of-type {
  padding-top: 0;
}

.card-comments .card-comment img {
  height: 1.875rem;
  width: 1.875rem;
  float: left;
}

.card-comments .comment-text {
  color: #78838e;
  margin-left: 40px;
}

.card-comments .username {
  color: #495057;
  display: block;
  font-weight: 600;
}

.card-comments .text-muted {
  font-size: 12px;
  font-weight: 400;
}

.todo-list {
  list-style: none;
  margin: 0;
  overflow: auto;
  padding: 0;
}

.todo-list > li {
  border-radius: 2px;
  background: #f8f9fa;
  border-left: 2px solid #e9ecef;
  color: #495057;
  margin-bottom: 2px;
  padding: 10px;
}

.todo-list > li:last-of-type {
  margin-bottom: 0;
}

.todo-list > li > input[type='checkbox'] {
  margin: 0 10px 0 5px;
}

.todo-list > li .text {
  display: inline-block;
  font-weight: 600;
  margin-left: 5px;
}

.todo-list > li .badge {
  font-size: .7rem;
  margin-left: 10px;
}

.todo-list > li .tools {
  color: #dc3545;
  display: none;
  float: right;
}

.todo-list > li .tools > .fa,
.todo-list > li .tools > .fas,
.todo-list > li .tools > .far,
.todo-list > li .tools > .fab,
.todo-list > li .tools > .glyphicon,
.todo-list > li .tools > .ion {
  cursor: pointer;
  margin-right: 5px;
}

.todo-list > li:hover .tools {
  display: inline-block;
}

.todo-list > li.done {
  color: #697582;
}

.todo-list > li.done .text {
  font-weight: 500;
  text-decoration: line-through;
}

.todo-list > li.done .badge {
  background: #adb5bd !important;
}

.todo-list .primary {
  border-left-color: #007bff;
}

.todo-list .secondary {
  border-left-color: #6c757d;
}

.todo-list .success {
  border-left-color: #28a745;
}

.todo-list .info {
  border-left-color: #17a2b8;
}

.todo-list .warning {
  border-left-color: #ffc107;
}

.todo-list .danger {
  border-left-color: #dc3545;
}

.todo-list .light {
  border-left-color: #f8f9fa;
}

.todo-list .dark {
  border-left-color: #343a40;
}

.todo-list .navy {
  border-left-color: #001f3f;
}

.todo-list .olive {
  border-left-color: #3d9970;
}

.todo-list .lime {
  border-left-color: #01ff70;
}

.todo-list .fuchsia {
  border-left-color: #f012be;
}

.todo-list .maroon {
  border-left-color: #d81b60;
}

.todo-list .blue {
  border-left-color: #007bff;
}

.todo-list .indigo {
  border-left-color: #6610f2;
}

.todo-list .purple {
  border-left-color: #6f42c1;
}

.todo-list .pink {
  border-left-color: #e83e8c;
}

.todo-list .red {
  border-left-color: #dc3545;
}

.todo-list .orange {
  border-left-color: #fd7e14;
}

.todo-list .yellow {
  border-left-color: #ffc107;
}

.todo-list .green {
  border-left-color: #28a745;
}

.todo-list .teal {
  border-left-color: #20c997;
}

.todo-list .cyan {
  border-left-color: #17a2b8;
}

.todo-list .white {
  border-left-color: #ffffff;
}

.todo-list .gray {
  border-left-color: #6c757d;
}

.todo-list .gray-dark {
  border-left-color: #343a40;
}

.todo-list .handle {
  cursor: move;
  display: inline-block;
  margin: 0 5px;
}

.card-input {
  max-width: 200px;
}

.card-primary.card-tabs:not(.card-outline) .card-header {
  background-color: #007bff;
}

.card-primary.card-tabs:not(.card-outline) .card-header,
.card-primary.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-primary.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-primary.card-tabs.card-outline {
  border-top: 3px solid #007bff;
}

.card-primary.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-primary.card-outline-tabs .card-header a.active {
  border-top: 3px solid #007bff;
}

.bg-primary .btn-tool,
.bg-gradient-primary .btn-tool,
.card-primary:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-primary .btn-tool:hover,
.bg-gradient-primary .btn-tool:hover,
.card-primary:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-primary .bootstrap-datetimepicker-widget .table td,
.card.bg-primary .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-primary .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-primary .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-primary .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-primary .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-primary .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget table td.second:hover {
  background: #0067d6;
  color: #ffffff;
}

.card.bg-primary .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-primary .bootstrap-datetimepicker-widget table td.active,
.card.bg-primary .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-primary .bootstrap-datetimepicker-widget table td.active:hover {
  background: #3395ff;
  color: #ffffff;
}

.card-secondary.card-tabs:not(.card-outline) .card-header {
  background-color: #6c757d;
}

.card-secondary.card-tabs:not(.card-outline) .card-header,
.card-secondary.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-secondary.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-secondary.card-tabs.card-outline {
  border-top: 3px solid #6c757d;
}

.card-secondary.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-secondary.card-outline-tabs .card-header a.active {
  border-top: 3px solid #6c757d;
}

.bg-secondary .btn-tool,
.bg-gradient-secondary .btn-tool,
.card-secondary:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-secondary .btn-tool:hover,
.bg-gradient-secondary .btn-tool:hover,
.card-secondary:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-secondary .bootstrap-datetimepicker-widget .table td,
.card.bg-secondary .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-secondary .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-secondary .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-secondary .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-secondary .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-secondary .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget table td.second:hover {
  background: #596167;
  color: #ffffff;
}

.card.bg-secondary .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-secondary .bootstrap-datetimepicker-widget table td.active,
.card.bg-secondary .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-secondary .bootstrap-datetimepicker-widget table td.active:hover {
  background: #868e96;
  color: #ffffff;
}

.card-success.card-tabs:not(.card-outline) .card-header {
  background-color: #28a745;
}

.card-success.card-tabs:not(.card-outline) .card-header,
.card-success.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-success.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-success.card-tabs.card-outline {
  border-top: 3px solid #28a745;
}

.card-success.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-success.card-outline-tabs .card-header a.active {
  border-top: 3px solid #28a745;
}

.bg-success .btn-tool,
.bg-gradient-success .btn-tool,
.card-success:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-success .btn-tool:hover,
.bg-gradient-success .btn-tool:hover,
.card-success:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-success .bootstrap-datetimepicker-widget .table td,
.card.bg-success .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-success .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-success .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-success .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-success .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-success .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-success .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-success .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-success .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-success .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-success .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-success .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-success .bootstrap-datetimepicker-widget table td.second:hover {
  background: #208637;
  color: #ffffff;
}

.card.bg-success .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-success .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-success .bootstrap-datetimepicker-widget table td.active,
.card.bg-success .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-success .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-success .bootstrap-datetimepicker-widget table td.active:hover {
  background: #34ce57;
  color: #ffffff;
}

.card-info.card-tabs:not(.card-outline) .card-header {
  background-color: #17a2b8;
}

.card-info.card-tabs:not(.card-outline) .card-header,
.card-info.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-info.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-info.card-tabs.card-outline {
  border-top: 3px solid #17a2b8;
}

.card-info.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-info.card-outline-tabs .card-header a.active {
  border-top: 3px solid #17a2b8;
}

.bg-info .btn-tool,
.bg-gradient-info .btn-tool,
.card-info:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-info .btn-tool:hover,
.bg-gradient-info .btn-tool:hover,
.card-info:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-info .bootstrap-datetimepicker-widget .table td,
.card.bg-info .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-info .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-info .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-info .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-info .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-info .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-info .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-info .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-info .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-info .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-info .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-info .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-info .bootstrap-datetimepicker-widget table td.second:hover {
  background: #128294;
  color: #ffffff;
}

.card.bg-info .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-info .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-info .bootstrap-datetimepicker-widget table td.active,
.card.bg-info .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-info .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-info .bootstrap-datetimepicker-widget table td.active:hover {
  background: #1fc8e3;
  color: #ffffff;
}

.card-warning.card-tabs:not(.card-outline) .card-header {
  background-color: #ffc107;
}

.card-warning.card-tabs:not(.card-outline) .card-header,
.card-warning.card-tabs:not(.card-outline) .card-header a {
  color: #1F2D3D;
}

.card-warning.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-warning.card-tabs.card-outline {
  border-top: 3px solid #ffc107;
}

.card-warning.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-warning.card-outline-tabs .card-header a.active {
  border-top: 3px solid #ffc107;
}

.bg-warning .btn-tool,
.bg-gradient-warning .btn-tool,
.card-warning:not(.card-outline) .btn-tool {
  color: rgba(31, 45, 61, 0.8);
}

.bg-warning .btn-tool:hover,
.bg-gradient-warning .btn-tool:hover,
.card-warning:not(.card-outline) .btn-tool:hover {
  color: #1F2D3D;
}

.card.bg-warning .bootstrap-datetimepicker-widget .table td,
.card.bg-warning .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-warning .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-warning .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-warning .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-warning .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-warning .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget table td.second:hover {
  background: #dda600;
  color: #1F2D3D;
}

.card.bg-warning .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #1F2D3D;
}

.card.bg-warning .bootstrap-datetimepicker-widget table td.active,
.card.bg-warning .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-warning .bootstrap-datetimepicker-widget table td.active:hover {
  background: #ffce3a;
  color: #1F2D3D;
}

.card-danger.card-tabs:not(.card-outline) .card-header {
  background-color: #dc3545;
}

.card-danger.card-tabs:not(.card-outline) .card-header,
.card-danger.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-danger.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-danger.card-tabs.card-outline {
  border-top: 3px solid #dc3545;
}

.card-danger.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-danger.card-outline-tabs .card-header a.active {
  border-top: 3px solid #dc3545;
}

.bg-danger .btn-tool,
.bg-gradient-danger .btn-tool,
.card-danger:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-danger .btn-tool:hover,
.bg-gradient-danger .btn-tool:hover,
.card-danger:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-danger .bootstrap-datetimepicker-widget .table td,
.card.bg-danger .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-danger .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-danger .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-danger .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-danger .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-danger .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget table td.second:hover {
  background: #c62232;
  color: #ffffff;
}

.card.bg-danger .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-danger .bootstrap-datetimepicker-widget table td.active,
.card.bg-danger .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-danger .bootstrap-datetimepicker-widget table td.active:hover {
  background: #e4606d;
  color: #ffffff;
}

.card-light.card-tabs:not(.card-outline) .card-header {
  background-color: #f8f9fa;
}

.card-light.card-tabs:not(.card-outline) .card-header,
.card-light.card-tabs:not(.card-outline) .card-header a {
  color: #1F2D3D;
}

.card-light.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-light.card-tabs.card-outline {
  border-top: 3px solid #f8f9fa;
}

.card-light.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-light.card-outline-tabs .card-header a.active {
  border-top: 3px solid #f8f9fa;
}

.bg-light .btn-tool,
.bg-gradient-light .btn-tool,
.card-light:not(.card-outline) .btn-tool {
  color: rgba(31, 45, 61, 0.8);
}

.bg-light .btn-tool:hover,
.bg-gradient-light .btn-tool:hover,
.card-light:not(.card-outline) .btn-tool:hover {
  color: #1F2D3D;
}

.card.bg-light .bootstrap-datetimepicker-widget .table td,
.card.bg-light .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-light .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-light .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-light .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-light .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-light .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-light .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-light .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-light .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-light .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-light .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-light .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-light .bootstrap-datetimepicker-widget table td.second:hover {
  background: #e0e5e9;
  color: #1F2D3D;
}

.card.bg-light .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-light .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #1F2D3D;
}

.card.bg-light .bootstrap-datetimepicker-widget table td.active,
.card.bg-light .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-light .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-light .bootstrap-datetimepicker-widget table td.active:hover {
  background: white;
  color: #1F2D3D;
}

.card-dark.card-tabs:not(.card-outline) .card-header {
  background-color: #343a40;
}

.card-dark.card-tabs:not(.card-outline) .card-header,
.card-dark.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-dark.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-dark.card-tabs.card-outline {
  border-top: 3px solid #343a40;
}

.card-dark.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-dark.card-outline-tabs .card-header a.active {
  border-top: 3px solid #343a40;
}

.bg-dark .btn-tool,
.bg-gradient-dark .btn-tool,
.card-dark:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-dark .btn-tool:hover,
.bg-gradient-dark .btn-tool:hover,
.card-dark:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-dark .bootstrap-datetimepicker-widget .table td,
.card.bg-dark .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-dark .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-dark .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-dark .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-dark .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-dark .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget table td.second:hover {
  background: #222629;
  color: #ffffff;
}

.card.bg-dark .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-dark .bootstrap-datetimepicker-widget table td.active,
.card.bg-dark .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-dark .bootstrap-datetimepicker-widget table td.active:hover {
  background: #4b545c;
  color: #ffffff;
}

.card-navy.card-tabs:not(.card-outline) .card-header {
  background-color: #001f3f;
}

.card-navy.card-tabs:not(.card-outline) .card-header,
.card-navy.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-navy.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-navy.card-tabs.card-outline {
  border-top: 3px solid #001f3f;
}

.card-navy.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-navy.card-outline-tabs .card-header a.active {
  border-top: 3px solid #001f3f;
}

.bg-navy .btn-tool,
.bg-gradient-navy .btn-tool,
.card-navy:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-navy .btn-tool:hover,
.bg-gradient-navy .btn-tool:hover,
.card-navy:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-navy .bootstrap-datetimepicker-widget .table td,
.card.bg-navy .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-navy .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-navy .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-navy .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-navy .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-navy .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget table td.second:hover {
  background: #000b16;
  color: #ffffff;
}

.card.bg-navy .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-navy .bootstrap-datetimepicker-widget table td.active,
.card.bg-navy .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-navy .bootstrap-datetimepicker-widget table td.active:hover {
  background: #003872;
  color: #ffffff;
}

.card-olive.card-tabs:not(.card-outline) .card-header {
  background-color: #3d9970;
}

.card-olive.card-tabs:not(.card-outline) .card-header,
.card-olive.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-olive.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-olive.card-tabs.card-outline {
  border-top: 3px solid #3d9970;
}

.card-olive.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-olive.card-outline-tabs .card-header a.active {
  border-top: 3px solid #3d9970;
}

.bg-olive .btn-tool,
.bg-gradient-olive .btn-tool,
.card-olive:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-olive .btn-tool:hover,
.bg-gradient-olive .btn-tool:hover,
.card-olive:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-olive .bootstrap-datetimepicker-widget .table td,
.card.bg-olive .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-olive .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-olive .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-olive .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-olive .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-olive .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget table td.second:hover {
  background: #317c5b;
  color: #ffffff;
}

.card.bg-olive .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-olive .bootstrap-datetimepicker-widget table td.active,
.card.bg-olive .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-olive .bootstrap-datetimepicker-widget table td.active:hover {
  background: #50b98a;
  color: #ffffff;
}

.card-lime.card-tabs:not(.card-outline) .card-header {
  background-color: #01ff70;
}

.card-lime.card-tabs:not(.card-outline) .card-header,
.card-lime.card-tabs:not(.card-outline) .card-header a {
  color: #1F2D3D;
}

.card-lime.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-lime.card-tabs.card-outline {
  border-top: 3px solid #01ff70;
}

.card-lime.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-lime.card-outline-tabs .card-header a.active {
  border-top: 3px solid #01ff70;
}

.bg-lime .btn-tool,
.bg-gradient-lime .btn-tool,
.card-lime:not(.card-outline) .btn-tool {
  color: rgba(31, 45, 61, 0.8);
}

.bg-lime .btn-tool:hover,
.bg-gradient-lime .btn-tool:hover,
.card-lime:not(.card-outline) .btn-tool:hover {
  color: #1F2D3D;
}

.card.bg-lime .bootstrap-datetimepicker-widget .table td,
.card.bg-lime .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-lime .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-lime .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-lime .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-lime .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-lime .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget table td.second:hover {
  background: #00d75e;
  color: #1F2D3D;
}

.card.bg-lime .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #1F2D3D;
}

.card.bg-lime .bootstrap-datetimepicker-widget table td.active,
.card.bg-lime .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-lime .bootstrap-datetimepicker-widget table td.active:hover {
  background: #34ff8d;
  color: #1F2D3D;
}

.card-fuchsia.card-tabs:not(.card-outline) .card-header {
  background-color: #f012be;
}

.card-fuchsia.card-tabs:not(.card-outline) .card-header,
.card-fuchsia.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-fuchsia.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-fuchsia.card-tabs.card-outline {
  border-top: 3px solid #f012be;
}

.card-fuchsia.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-fuchsia.card-outline-tabs .card-header a.active {
  border-top: 3px solid #f012be;
}

.bg-fuchsia .btn-tool,
.bg-gradient-fuchsia .btn-tool,
.card-fuchsia:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-fuchsia .btn-tool:hover,
.bg-gradient-fuchsia .btn-tool:hover,
.card-fuchsia:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-fuchsia .bootstrap-datetimepicker-widget .table td,
.card.bg-fuchsia .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-fuchsia .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-fuchsia .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-fuchsia .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-fuchsia .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-fuchsia .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget table td.second:hover {
  background: #cc0da1;
  color: #ffffff;
}

.card.bg-fuchsia .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-fuchsia .bootstrap-datetimepicker-widget table td.active,
.card.bg-fuchsia .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-fuchsia .bootstrap-datetimepicker-widget table td.active:hover {
  background: #f342cb;
  color: #ffffff;
}

.card-maroon.card-tabs:not(.card-outline) .card-header {
  background-color: #d81b60;
}

.card-maroon.card-tabs:not(.card-outline) .card-header,
.card-maroon.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-maroon.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-maroon.card-tabs.card-outline {
  border-top: 3px solid #d81b60;
}

.card-maroon.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-maroon.card-outline-tabs .card-header a.active {
  border-top: 3px solid #d81b60;
}

.bg-maroon .btn-tool,
.bg-gradient-maroon .btn-tool,
.card-maroon:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-maroon .btn-tool:hover,
.bg-gradient-maroon .btn-tool:hover,
.card-maroon:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-maroon .bootstrap-datetimepicker-widget .table td,
.card.bg-maroon .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-maroon .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-maroon .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-maroon .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-maroon .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-maroon .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget table td.second:hover {
  background: #b41650;
  color: #ffffff;
}

.card.bg-maroon .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-maroon .bootstrap-datetimepicker-widget table td.active,
.card.bg-maroon .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-maroon .bootstrap-datetimepicker-widget table td.active:hover {
  background: #e73f7c;
  color: #ffffff;
}

.card-blue.card-tabs:not(.card-outline) .card-header {
  background-color: #007bff;
}

.card-blue.card-tabs:not(.card-outline) .card-header,
.card-blue.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-blue.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-blue.card-tabs.card-outline {
  border-top: 3px solid #007bff;
}

.card-blue.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-blue.card-outline-tabs .card-header a.active {
  border-top: 3px solid #007bff;
}

.bg-blue .btn-tool,
.bg-gradient-blue .btn-tool,
.card-blue:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-blue .btn-tool:hover,
.bg-gradient-blue .btn-tool:hover,
.card-blue:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-blue .bootstrap-datetimepicker-widget .table td,
.card.bg-blue .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-blue .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-blue .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-blue .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-blue .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-blue .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget table td.second:hover {
  background: #0067d6;
  color: #ffffff;
}

.card.bg-blue .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-blue .bootstrap-datetimepicker-widget table td.active,
.card.bg-blue .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-blue .bootstrap-datetimepicker-widget table td.active:hover {
  background: #3395ff;
  color: #ffffff;
}

.card-indigo.card-tabs:not(.card-outline) .card-header {
  background-color: #6610f2;
}

.card-indigo.card-tabs:not(.card-outline) .card-header,
.card-indigo.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-indigo.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-indigo.card-tabs.card-outline {
  border-top: 3px solid #6610f2;
}

.card-indigo.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-indigo.card-outline-tabs .card-header a.active {
  border-top: 3px solid #6610f2;
}

.bg-indigo .btn-tool,
.bg-gradient-indigo .btn-tool,
.card-indigo:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-indigo .btn-tool:hover,
.bg-gradient-indigo .btn-tool:hover,
.card-indigo:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-indigo .bootstrap-datetimepicker-widget .table td,
.card.bg-indigo .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-indigo .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-indigo .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-indigo .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-indigo .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-indigo .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget table td.second:hover {
  background: #550bce;
  color: #ffffff;
}

.card.bg-indigo .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-indigo .bootstrap-datetimepicker-widget table td.active,
.card.bg-indigo .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-indigo .bootstrap-datetimepicker-widget table td.active:hover {
  background: #8540f5;
  color: #ffffff;
}

.card-purple.card-tabs:not(.card-outline) .card-header {
  background-color: #6f42c1;
}

.card-purple.card-tabs:not(.card-outline) .card-header,
.card-purple.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-purple.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-purple.card-tabs.card-outline {
  border-top: 3px solid #6f42c1;
}

.card-purple.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-purple.card-outline-tabs .card-header a.active {
  border-top: 3px solid #6f42c1;
}

.bg-purple .btn-tool,
.bg-gradient-purple .btn-tool,
.card-purple:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-purple .btn-tool:hover,
.bg-gradient-purple .btn-tool:hover,
.card-purple:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-purple .bootstrap-datetimepicker-widget .table td,
.card.bg-purple .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-purple .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-purple .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-purple .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-purple .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-purple .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget table td.second:hover {
  background: #5d36a4;
  color: #ffffff;
}

.card.bg-purple .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-purple .bootstrap-datetimepicker-widget table td.active,
.card.bg-purple .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-purple .bootstrap-datetimepicker-widget table td.active:hover {
  background: #8c68ce;
  color: #ffffff;
}

.card-pink.card-tabs:not(.card-outline) .card-header {
  background-color: #e83e8c;
}

.card-pink.card-tabs:not(.card-outline) .card-header,
.card-pink.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-pink.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-pink.card-tabs.card-outline {
  border-top: 3px solid #e83e8c;
}

.card-pink.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-pink.card-outline-tabs .card-header a.active {
  border-top: 3px solid #e83e8c;
}

.bg-pink .btn-tool,
.bg-gradient-pink .btn-tool,
.card-pink:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-pink .btn-tool:hover,
.bg-gradient-pink .btn-tool:hover,
.card-pink:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-pink .bootstrap-datetimepicker-widget .table td,
.card.bg-pink .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-pink .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-pink .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-pink .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-pink .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-pink .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget table td.second:hover {
  background: #e21b76;
  color: #ffffff;
}

.card.bg-pink .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-pink .bootstrap-datetimepicker-widget table td.active,
.card.bg-pink .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-pink .bootstrap-datetimepicker-widget table td.active:hover {
  background: #ed6ca7;
  color: #ffffff;
}

.card-red.card-tabs:not(.card-outline) .card-header {
  background-color: #dc3545;
}

.card-red.card-tabs:not(.card-outline) .card-header,
.card-red.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-red.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-red.card-tabs.card-outline {
  border-top: 3px solid #dc3545;
}

.card-red.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-red.card-outline-tabs .card-header a.active {
  border-top: 3px solid #dc3545;
}

.bg-red .btn-tool,
.bg-gradient-red .btn-tool,
.card-red:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-red .btn-tool:hover,
.bg-gradient-red .btn-tool:hover,
.card-red:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-red .bootstrap-datetimepicker-widget .table td,
.card.bg-red .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-red .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-red .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-red .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-red .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-red .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-red .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-red .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-red .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-red .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-red .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-red .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-red .bootstrap-datetimepicker-widget table td.second:hover {
  background: #c62232;
  color: #ffffff;
}

.card.bg-red .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-red .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-red .bootstrap-datetimepicker-widget table td.active,
.card.bg-red .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-red .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-red .bootstrap-datetimepicker-widget table td.active:hover {
  background: #e4606d;
  color: #ffffff;
}

.card-orange.card-tabs:not(.card-outline) .card-header {
  background-color: #fd7e14;
}

.card-orange.card-tabs:not(.card-outline) .card-header,
.card-orange.card-tabs:not(.card-outline) .card-header a {
  color: #1F2D3D;
}

.card-orange.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-orange.card-tabs.card-outline {
  border-top: 3px solid #fd7e14;
}

.card-orange.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-orange.card-outline-tabs .card-header a.active {
  border-top: 3px solid #fd7e14;
}

.bg-orange .btn-tool,
.bg-gradient-orange .btn-tool,
.card-orange:not(.card-outline) .btn-tool {
  color: rgba(31, 45, 61, 0.8);
}

.bg-orange .btn-tool:hover,
.bg-gradient-orange .btn-tool:hover,
.card-orange:not(.card-outline) .btn-tool:hover {
  color: #1F2D3D;
}

.card.bg-orange .bootstrap-datetimepicker-widget .table td,
.card.bg-orange .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-orange .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-orange .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-orange .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-orange .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-orange .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget table td.second:hover {
  background: #e66a02;
  color: #1F2D3D;
}

.card.bg-orange .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #1F2D3D;
}

.card.bg-orange .bootstrap-datetimepicker-widget table td.active,
.card.bg-orange .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-orange .bootstrap-datetimepicker-widget table td.active:hover {
  background: #fd9a47;
  color: #1F2D3D;
}

.card-yellow.card-tabs:not(.card-outline) .card-header {
  background-color: #ffc107;
}

.card-yellow.card-tabs:not(.card-outline) .card-header,
.card-yellow.card-tabs:not(.card-outline) .card-header a {
  color: #1F2D3D;
}

.card-yellow.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-yellow.card-tabs.card-outline {
  border-top: 3px solid #ffc107;
}

.card-yellow.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-yellow.card-outline-tabs .card-header a.active {
  border-top: 3px solid #ffc107;
}

.bg-yellow .btn-tool,
.bg-gradient-yellow .btn-tool,
.card-yellow:not(.card-outline) .btn-tool {
  color: rgba(31, 45, 61, 0.8);
}

.bg-yellow .btn-tool:hover,
.bg-gradient-yellow .btn-tool:hover,
.card-yellow:not(.card-outline) .btn-tool:hover {
  color: #1F2D3D;
}

.card.bg-yellow .bootstrap-datetimepicker-widget .table td,
.card.bg-yellow .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-yellow .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-yellow .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-yellow .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-yellow .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-yellow .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget table td.second:hover {
  background: #dda600;
  color: #1F2D3D;
}

.card.bg-yellow .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #1F2D3D;
}

.card.bg-yellow .bootstrap-datetimepicker-widget table td.active,
.card.bg-yellow .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-yellow .bootstrap-datetimepicker-widget table td.active:hover {
  background: #ffce3a;
  color: #1F2D3D;
}

.card-green.card-tabs:not(.card-outline) .card-header {
  background-color: #28a745;
}

.card-green.card-tabs:not(.card-outline) .card-header,
.card-green.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-green.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-green.card-tabs.card-outline {
  border-top: 3px solid #28a745;
}

.card-green.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-green.card-outline-tabs .card-header a.active {
  border-top: 3px solid #28a745;
}

.bg-green .btn-tool,
.bg-gradient-green .btn-tool,
.card-green:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-green .btn-tool:hover,
.bg-gradient-green .btn-tool:hover,
.card-green:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-green .bootstrap-datetimepicker-widget .table td,
.card.bg-green .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-green .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-green .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-green .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-green .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-green .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-green .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-green .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-green .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-green .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-green .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-green .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-green .bootstrap-datetimepicker-widget table td.second:hover {
  background: #208637;
  color: #ffffff;
}

.card.bg-green .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-green .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-green .bootstrap-datetimepicker-widget table td.active,
.card.bg-green .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-green .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-green .bootstrap-datetimepicker-widget table td.active:hover {
  background: #34ce57;
  color: #ffffff;
}

.card-teal.card-tabs:not(.card-outline) .card-header {
  background-color: #20c997;
}

.card-teal.card-tabs:not(.card-outline) .card-header,
.card-teal.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-teal.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-teal.card-tabs.card-outline {
  border-top: 3px solid #20c997;
}

.card-teal.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-teal.card-outline-tabs .card-header a.active {
  border-top: 3px solid #20c997;
}

.bg-teal .btn-tool,
.bg-gradient-teal .btn-tool,
.card-teal:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-teal .btn-tool:hover,
.bg-gradient-teal .btn-tool:hover,
.card-teal:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-teal .bootstrap-datetimepicker-widget .table td,
.card.bg-teal .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-teal .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-teal .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-teal .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-teal .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-teal .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget table td.second:hover {
  background: #1aa67d;
  color: #ffffff;
}

.card.bg-teal .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-teal .bootstrap-datetimepicker-widget table td.active,
.card.bg-teal .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-teal .bootstrap-datetimepicker-widget table td.active:hover {
  background: #3ce0af;
  color: #ffffff;
}

.card-cyan.card-tabs:not(.card-outline) .card-header {
  background-color: #17a2b8;
}

.card-cyan.card-tabs:not(.card-outline) .card-header,
.card-cyan.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-cyan.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-cyan.card-tabs.card-outline {
  border-top: 3px solid #17a2b8;
}

.card-cyan.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-cyan.card-outline-tabs .card-header a.active {
  border-top: 3px solid #17a2b8;
}

.bg-cyan .btn-tool,
.bg-gradient-cyan .btn-tool,
.card-cyan:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-cyan .btn-tool:hover,
.bg-gradient-cyan .btn-tool:hover,
.card-cyan:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-cyan .bootstrap-datetimepicker-widget .table td,
.card.bg-cyan .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-cyan .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-cyan .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-cyan .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-cyan .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-cyan .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget table td.second:hover {
  background: #128294;
  color: #ffffff;
}

.card.bg-cyan .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-cyan .bootstrap-datetimepicker-widget table td.active,
.card.bg-cyan .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-cyan .bootstrap-datetimepicker-widget table td.active:hover {
  background: #1fc8e3;
  color: #ffffff;
}

.card-white.card-tabs:not(.card-outline) .card-header {
  background-color: #ffffff;
}

.card-white.card-tabs:not(.card-outline) .card-header,
.card-white.card-tabs:not(.card-outline) .card-header a {
  color: #1F2D3D;
}

.card-white.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-white.card-tabs.card-outline {
  border-top: 3px solid #ffffff;
}

.card-white.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-white.card-outline-tabs .card-header a.active {
  border-top: 3px solid #ffffff;
}

.bg-white .btn-tool,
.bg-gradient-white .btn-tool,
.card-white:not(.card-outline) .btn-tool {
  color: rgba(31, 45, 61, 0.8);
}

.bg-white .btn-tool:hover,
.bg-gradient-white .btn-tool:hover,
.card-white:not(.card-outline) .btn-tool:hover {
  color: #1F2D3D;
}

.card.bg-white .bootstrap-datetimepicker-widget .table td,
.card.bg-white .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-white .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-white .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-white .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-white .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-white .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-white .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-white .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-white .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-white .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-white .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-white .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-white .bootstrap-datetimepicker-widget table td.second:hover {
  background: #ebebeb;
  color: #1F2D3D;
}

.card.bg-white .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-white .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #1F2D3D;
}

.card.bg-white .bootstrap-datetimepicker-widget table td.active,
.card.bg-white .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-white .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-white .bootstrap-datetimepicker-widget table td.active:hover {
  background: white;
  color: #1F2D3D;
}

.card-gray.card-tabs:not(.card-outline) .card-header {
  background-color: #6c757d;
}

.card-gray.card-tabs:not(.card-outline) .card-header,
.card-gray.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-gray.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-gray.card-tabs.card-outline {
  border-top: 3px solid #6c757d;
}

.card-gray.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-gray.card-outline-tabs .card-header a.active {
  border-top: 3px solid #6c757d;
}

.bg-gray .btn-tool,
.bg-gradient-gray .btn-tool,
.card-gray:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-gray .btn-tool:hover,
.bg-gradient-gray .btn-tool:hover,
.card-gray:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-gray .bootstrap-datetimepicker-widget .table td,
.card.bg-gray .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-gray .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gray .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gray .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gray .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gray .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget table td.second:hover {
  background: #596167;
  color: #ffffff;
}

.card.bg-gray .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-gray .bootstrap-datetimepicker-widget table td.active,
.card.bg-gray .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-gray .bootstrap-datetimepicker-widget table td.active:hover {
  background: #868e96;
  color: #ffffff;
}

.card-gray-dark.card-tabs:not(.card-outline) .card-header {
  background-color: #343a40;
}

.card-gray-dark.card-tabs:not(.card-outline) .card-header,
.card-gray-dark.card-tabs:not(.card-outline) .card-header a {
  color: #ffffff;
}

.card-gray-dark.card-tabs:not(.card-outline) .card-header a.active {
  color: #1F2D3D;
}

.card-gray-dark.card-tabs.card-outline {
  border-top: 3px solid #343a40;
}

.card-gray-dark.card-outline-tabs .card-header a:hover {
  border-top: 3px solid #dee2e6;
}

.card-gray-dark.card-outline-tabs .card-header a.active {
  border-top: 3px solid #343a40;
}

.bg-gray-dark .btn-tool,
.bg-gradient-gray-dark .btn-tool,
.card-gray-dark:not(.card-outline) .btn-tool {
  color: rgba(255, 255, 255, 0.8);
}

.bg-gray-dark .btn-tool:hover,
.bg-gradient-gray-dark .btn-tool:hover,
.card-gray-dark:not(.card-outline) .btn-tool:hover {
  color: #ffffff;
}

.card.bg-gray-dark .bootstrap-datetimepicker-widget .table td,
.card.bg-gray-dark .bootstrap-datetimepicker-widget .table th,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget .table td,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget .table th {
  border: none;
}

.card.bg-gray-dark .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gray-dark .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gray-dark .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gray-dark .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gray-dark .bootstrap-datetimepicker-widget table td.second:hover,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget table thead tr:first-child th:hover,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget table td.day:hover,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget table td.hour:hover,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget table td.minute:hover,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget table td.second:hover {
  background: #222629;
  color: #ffffff;
}

.card.bg-gray-dark .bootstrap-datetimepicker-widget table td.today::before,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget table td.today::before {
  border-bottom-color: #ffffff;
}

.card.bg-gray-dark .bootstrap-datetimepicker-widget table td.active,
.card.bg-gray-dark .bootstrap-datetimepicker-widget table td.active:hover,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget table td.active,
.card.bg-gradient-gray-dark .bootstrap-datetimepicker-widget table td.active:hover {
  background: #4b545c;
  color: #ffffff;
}

.card-default .nav-item:first-child .nav-link {
  border-left: 0;
}

.modal-dialog .overlay {
  background-color: #000;
  display: block;
  height: 100%;
  left: 0;
  opacity: .7;
  position: absolute;
  top: 0;
  width: 100%;
  z-index: 1052;
}

.modal-content.bg-warning .modal-header,
.modal-content.bg-warning .modal-footer {
  border-color: #343a40;
}

.modal-content.bg-primary .close, .modal-content.bg-secondary .close, .modal-content.bg-info .close, .modal-content.bg-danger .close, .modal-content.bg-success .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toasts-top-right {
  position: absolute;
  right: 0;
  top: 0;
  z-index: 1040;
}

.toasts-top-right.fixed {
  position: fixed;
}

.toasts-top-left {
  left: 0;
  position: absolute;
  top: 0;
  z-index: 1040;
}

.toasts-top-left.fixed {
  position: fixed;
}

.toasts-bottom-right {
  bottom: 0;
  position: absolute;
  right: 0;
  z-index: 1040;
}

.toasts-bottom-right.fixed {
  position: fixed;
}

.toasts-bottom-left {
  bottom: 0;
  left: 0;
  position: absolute;
  z-index: 1040;
}

.toasts-bottom-left.fixed {
  position: fixed;
}

.toast.bg-primary {
  background: rgba(0, 123, 255, 0.9) !important;
}

.toast.bg-primary .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-primary .toast-header {
  background: rgba(0, 123, 255, 0.85);
  color: #ffffff;
}

.toast.bg-secondary {
  background: rgba(108, 117, 125, 0.9) !important;
}

.toast.bg-secondary .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-secondary .toast-header {
  background: rgba(108, 117, 125, 0.85);
  color: #ffffff;
}

.toast.bg-success {
  background: rgba(40, 167, 69, 0.9) !important;
}

.toast.bg-success .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-success .toast-header {
  background: rgba(40, 167, 69, 0.85);
  color: #ffffff;
}

.toast.bg-info {
  background: rgba(23, 162, 184, 0.9) !important;
}

.toast.bg-info .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-info .toast-header {
  background: rgba(23, 162, 184, 0.85);
  color: #ffffff;
}

.toast.bg-warning {
  background: rgba(255, 193, 7, 0.9) !important;
}

.toast.bg-warning .toast-header {
  background: rgba(255, 193, 7, 0.85);
  color: #1F2D3D;
}

.toast.bg-danger {
  background: rgba(220, 53, 69, 0.9) !important;
}

.toast.bg-danger .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-danger .toast-header {
  background: rgba(220, 53, 69, 0.85);
  color: #ffffff;
}

.toast.bg-light {
  background: rgba(248, 249, 250, 0.9) !important;
}

.toast.bg-light .toast-header {
  background: rgba(248, 249, 250, 0.85);
  color: #1F2D3D;
}

.toast.bg-dark {
  background: rgba(52, 58, 64, 0.9) !important;
}

.toast.bg-dark .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-dark .toast-header {
  background: rgba(52, 58, 64, 0.85);
  color: #ffffff;
}

.toast.bg-navy {
  background: rgba(0, 31, 63, 0.9) !important;
}

.toast.bg-navy .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-navy .toast-header {
  background: rgba(0, 31, 63, 0.85);
  color: #ffffff;
}

.toast.bg-olive {
  background: rgba(61, 153, 112, 0.9) !important;
}

.toast.bg-olive .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-olive .toast-header {
  background: rgba(61, 153, 112, 0.85);
  color: #ffffff;
}

.toast.bg-lime {
  background: rgba(1, 255, 112, 0.9) !important;
}

.toast.bg-lime .toast-header {
  background: rgba(1, 255, 112, 0.85);
  color: #1F2D3D;
}

.toast.bg-fuchsia {
  background: rgba(240, 18, 190, 0.9) !important;
}

.toast.bg-fuchsia .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-fuchsia .toast-header {
  background: rgba(240, 18, 190, 0.85);
  color: #ffffff;
}

.toast.bg-maroon {
  background: rgba(216, 27, 96, 0.9) !important;
}

.toast.bg-maroon .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-maroon .toast-header {
  background: rgba(216, 27, 96, 0.85);
  color: #ffffff;
}

.toast.bg-blue {
  background: rgba(0, 123, 255, 0.9) !important;
}

.toast.bg-blue .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-blue .toast-header {
  background: rgba(0, 123, 255, 0.85);
  color: #ffffff;
}

.toast.bg-indigo {
  background: rgba(102, 16, 242, 0.9) !important;
}

.toast.bg-indigo .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-indigo .toast-header {
  background: rgba(102, 16, 242, 0.85);
  color: #ffffff;
}

.toast.bg-purple {
  background: rgba(111, 66, 193, 0.9) !important;
}

.toast.bg-purple .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-purple .toast-header {
  background: rgba(111, 66, 193, 0.85);
  color: #ffffff;
}

.toast.bg-pink {
  background: rgba(232, 62, 140, 0.9) !important;
}

.toast.bg-pink .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-pink .toast-header {
  background: rgba(232, 62, 140, 0.85);
  color: #ffffff;
}

.toast.bg-red {
  background: rgba(220, 53, 69, 0.9) !important;
}

.toast.bg-red .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-red .toast-header {
  background: rgba(220, 53, 69, 0.85);
  color: #ffffff;
}

.toast.bg-orange {
  background: rgba(253, 126, 20, 0.9) !important;
}

.toast.bg-orange .toast-header {
  background: rgba(253, 126, 20, 0.85);
  color: #1F2D3D;
}

.toast.bg-yellow {
  background: rgba(255, 193, 7, 0.9) !important;
}

.toast.bg-yellow .toast-header {
  background: rgba(255, 193, 7, 0.85);
  color: #1F2D3D;
}

.toast.bg-green {
  background: rgba(40, 167, 69, 0.9) !important;
}

.toast.bg-green .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-green .toast-header {
  background: rgba(40, 167, 69, 0.85);
  color: #ffffff;
}

.toast.bg-teal {
  background: rgba(32, 201, 151, 0.9) !important;
}

.toast.bg-teal .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-teal .toast-header {
  background: rgba(32, 201, 151, 0.85);
  color: #ffffff;
}

.toast.bg-cyan {
  background: rgba(23, 162, 184, 0.9) !important;
}

.toast.bg-cyan .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-cyan .toast-header {
  background: rgba(23, 162, 184, 0.85);
  color: #ffffff;
}

.toast.bg-white {
  background: rgba(255, 255, 255, 0.9) !important;
}

.toast.bg-white .toast-header {
  background: rgba(255, 255, 255, 0.85);
  color: #1F2D3D;
}

.toast.bg-gray {
  background: rgba(108, 117, 125, 0.9) !important;
}

.toast.bg-gray .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-gray .toast-header {
  background: rgba(108, 117, 125, 0.85);
  color: #ffffff;
}

.toast.bg-gray-dark {
  background: rgba(52, 58, 64, 0.9) !important;
}

.toast.bg-gray-dark .close {
  color: #ffffff;
  text-shadow: 0 1px 0 #000;
}

.toast.bg-gray-dark .toast-header {
  background: rgba(52, 58, 64, 0.85);
  color: #ffffff;
}

.btn.disabled, .btn:disabled {
  cursor: not-allowed;
}

.btn.btn-flat {
  border-radius: 0;
  border-width: 1px;
  box-shadow: none;
}

.btn.btn-file {
  overflow: hidden;
  position: relative;
}

.btn.btn-file > input[type='file'] {
  background: #ffffff;
  cursor: inherit;
  display: block;
  font-size: 100px;
  min-height: 100%;
  min-width: 100%;
  opacity: 0;
  outline: none;
  position: absolute;
  right: 0;
  text-align: right;
  top: 0;
}

.text-sm .btn {
  font-size: 0.875rem !important;
}

.btn-default {
  background-color: #f8f9fa;
  border-color: #ddd;
  color: #444;
}

.btn-default:hover, .btn-default:active, .btn-default.hover {
  background-color: #e9ecef;
  color: #2b2b2b;
}

.btn-app {
  border-radius: 3px;
  background-color: #f8f9fa;
  border: 1px solid #ddd;
  color: #6c757d;
  font-size: 12px;
  height: 60px;
  margin: 0 0 10px 10px;
  min-width: 80px;
  padding: 15px 5px;
  position: relative;
  text-align: center;
}

.btn-app > .fa,
.btn-app > .fas,
.btn-app > .far,
.btn-app > .fab,
.btn-app > .glyphicon,
.btn-app > .ion {
  display: block;
  font-size: 20px;
}

.btn-app:hover {
  background: #f8f9fa;
  border-color: #aaaaaa;
  color: #444;
}

.btn-app:active, .btn-app:focus {
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}

.btn-app > .badge {
  font-size: 10px;
  font-weight: 400;
  position: absolute;
  right: -10px;
  top: -3px;
}

.btn-xs {
  padding: 0.125rem 0.25rem;
  font-size: 0.75rem;
  line-height: 1.5;
  border-radius: 0.15rem;
}

.callout {
  border-radius: 0.25rem;
  box-shadow: 0 1px 3px rgba(0, 0, 0, 0.12), 0 1px 2px rgba(0, 0, 0, 0.24);
  background-color: #ffffff;
  border-left: 5px solid #e9ecef;
  margin-bottom: 1rem;
  padding: 1rem;
}

.callout a {
  color: #495057;
  text-decoration: underline;
}

.callout a:hover {
  color: #e9ecef;
}

.callout p:last-child {
  margin-bottom: 0;
}

.callout.callout-danger {
  border-left-color: #bd2130;
}

.callout.callout-warning {
  border-left-color: #d39e00;
}

.callout.callout-info {
  border-left-color: #117a8b;
}

.callout.callout-success {
  border-left-color: #1e7e34;
}

.alert .icon {
  margin-right: 10px;
}

.alert .close {
  color: #000;
  opacity: .2;
}

.alert .close:hover {
  opacity: .5;
}

.alert a {
  color: #ffffff;
  text-decoration: underline;
}

.alert-primary {
  color: #ffffff;
  background: #007bff;
  border-color: #006fe6;
}

.alert-default-primary {
  color: #004085;
  background-color: #cce5ff;
  border-color: #b8daff;
}

.alert-default-primary hr {
  border-top-color: #9fcdff;
}

.alert-default-primary .alert-link {
  color: #002752;
}

.alert-secondary {
  color: #ffffff;
  background: #6c757d;
  border-color: #60686f;
}

.alert-default-secondary {
  color: #383d41;
  background-color: #e2e3e5;
  border-color: #d6d8db;
}

.alert-default-secondary hr {
  border-top-color: #c8cbcf;
}

.alert-default-secondary .alert-link {
  color: #202326;
}

.alert-success {
  color: #ffffff;
  background: #28a745;
  border-color: #23923d;
}

.alert-default-success {
  color: #155724;
  background-color: #d4edda;
  border-color: #c3e6cb;
}

.alert-default-success hr {
  border-top-color: #b1dfbb;
}

.alert-default-success .alert-link {
  color: #0b2e13;
}

.alert-info {
  color: #ffffff;
  background: #17a2b8;
  border-color: #148ea1;
}

.alert-default-info {
  color: #0c5460;
  background-color: #d1ecf1;
  border-color: #bee5eb;
}

.alert-default-info hr {
  border-top-color: #abdde5;
}

.alert-default-info .alert-link {
  color: #062c33;
}

.alert-warning {
  color: #1F2D3D;
  background: #ffc107;
  border-color: #edb100;
}

.alert-default-warning {
  color: #856404;
  background-color: #fff3cd;
  border-color: #ffeeba;
}

.alert-default-warning hr {
  border-top-color: #ffe8a1;
}

.alert-default-warning .alert-link {
  color: #533f03;
}

.alert-danger {
  color: #ffffff;
  background: #dc3545;
  border-color: #d32535;
}

.alert-default-danger {
  color: #721c24;
  background-color: #f8d7da;
  border-color: #f5c6cb;
}

.alert-default-danger hr {
  border-top-color: #f1b0b7;
}

.alert-default-danger .alert-link {
  color: #491217;
}

.alert-light {
  color: #1F2D3D;
  background: #f8f9fa;
  border-color: #e9ecef;
}

.alert-default-light {
  color: #818182;
  background-color: #fefefe;
  border-color: #fdfdfe;
}

.alert-default-light hr {
  border-top-color: #ececf6;
}

.alert-default-light .alert-link {
  color: #686868;
}

.alert-dark {
  color: #ffffff;
  background: #343a40;
  border-color: #292d32;
}

.alert-default-dark {
  color: #1b1e21;
  background-color: #d6d8d9;
  border-color: #c6c8ca;
}

.alert-default-dark hr {
  border-top-color: #b9bbbe;
}

.alert-default-dark .alert-link {
  color: #040505;
}

.table:not(.table-dark) {
  color: inherit;
}

.table.table-head-fixed thead tr:nth-child(1) th {
  background-color: #ffffff;
  border-bottom: 0;
  box-shadow: inset 0 1px 0 #dee2e6, inset 0 -1px 0 #dee2e6;
  position: sticky;
  top: 0;
  z-index: 10;
}

.table.table-head-fixed.table-dark thead tr:nth-child(1) th {
  background-color: #212529;
  box-shadow: inset 0 1px 0 #383f45, inset 0 -1px 0 #383f45;
}

.table.no-border,
.table.no-border td,
.table.no-border th {
  border: 0;
}

.table.text-center,
.table.text-center td,
.table.text-center th {
  text-align: center;
}

.table.table-valign-middle thead > tr > th,
.table.table-valign-middle thead > tr > td,
.table.table-valign-middle tbody > tr > th,
.table.table-valign-middle tbody > tr > td {
  vertical-align: middle;
}

.card-body.p-0 .table thead > tr > th:first-of-type,
.card-body.p-0 .table thead > tr > td:first-of-type,
.card-body.p-0 .table tbody > tr > th:first-of-type,
.card-body.p-0 .table tbody > tr > td:first-of-type {
  padding-left: 1.5rem;
}

.card-body.p-0 .table thead > tr > th:last-of-type,
.card-body.p-0 .table thead > tr > td:last-of-type,
.card-body.p-0 .table tbody > tr > th:last-of-type,
.card-body.p-0 .table tbody > tr > td:last-of-type {
  padding-right: 1.5rem;
}

.carousel-control.left, .carousel-control.right {
  background-image: none;
}

.carousel-control > .fa,
.carousel-control > .fas,
.carousel-control > .far,
.carousel-control > .fab,
.carousel-control > .glyphicon,
.carousel-control > .ion {
  display: inline-block;
  font-size: 40px;
  margin-top: -20px;
  position: absolute;
  top: 50%;
  z-index: 5;
}

/*# sourceMappingURL=adminlte.components.css.map */